@@ -1,4 +1,6 @@
-'''This variable provides an unique integer each time it is accessed.
+'''
+@anchor pydoc:grizzly.testdata.variables.integer_incrementer Integer Incrementer
+This variable provides an unique integer each time it is accessed.
 
 Useful to generate unique ID for each request.
 
@@ -12,13 +14,13 @@ The first value of an integer that is going to be used.
 
 ## Example
 
-```gherkin
-And value of variable "AtomicIntegerIncrementer.unique_id" is "100 | step=10"
+``` gherkin
+And value for variable "AtomicIntegerIncrementer.unique_id" is "100 | step=10"
 ```
 
 This can then be used in a template:
 
-```json
+``` json
 {
     "id": {{ AtomicIntegerIncrementer.unique_id }}
 }
@@ -30,7 +32,7 @@ from typing import Union, Dict, Any, Type, Optional, cast
 
 from grizzly_extras.arguments import split_value, parse_arguments
 
-from ...types import AtomicVariable
+from . import AtomicVariable
 
 
 def atomicintegerincrementer__base_type__(value: Union[str, int]) -> str:
