@@ -1,11 +1,13 @@
 # pylint: disable=line-too-long
-'''Listens for messages on IBM MQ.
+'''
+@anchor pydoc:grizzly.testdata.variables.messagequeue Messagequeue
+Listens for messages on IBM MQ.
 
-Use [transformer task](/grizzly/framework/usage/tasks/transformer/) to extract specific parts of the message.
+Use {@pylink grizzly.tasks.transformer} task to extract specific parts of the message.
 
 Grizzly *must* have been installed with the extra `mq` package and native IBM MQ libraries must be installed for being able to use this variable:
 
-```plain
+``` plain
 pip3 install grizzly-loadtester[mq]
 ```
 
@@ -25,11 +27,11 @@ content type, which needs to be specified as an argument (e.g. XPATH expressions
 
 ### URL format
 
-```plain
+``` plain
 mq[s]://[<username>:<password>@]<hostname>[:<port>]/?QueueManager=<queue manager>&Channel=<channel>[&KeyFile=<key repository path>[&SslCipher=<ssl cipher>][&CertLabel=<certificate label>]]
 ```
 
-All variables in the URL have support for [templating](/grizzly/framework/usage/variables/templating/).
+All variables in the URL have support for {@link framework.usage.variables.templating}.
 
 * `mq[s]` _str_ - must be specified, `mqs` implies connecting with TLS, if `KeyFile` is not set in querystring, it will look for a key repository in `./<username>`
 * `username` _str_ (optional) - username to authenticate with, default `None`
@@ -44,8 +46,8 @@ All variables in the URL have support for [templating](/grizzly/framework/usage/
 
 ## Example
 
-```gherkin
-And value of variable "AtomicMessageQueue.document_id" is "queue:IN.DOCUMENTS | wait=120, url='mqs://mq_subscription:$conf::mq.password@mq.example.com/?QueueManager=QM1&Channel=SRV.CONN', repeat=True"
+``` gherkin
+And value for variable "AtomicMessageQueue.document_id" is "queue:IN.DOCUMENTS | wait=120, url='mqs://mq_subscription:$conf::mq.password@mq.example.com/?QueueManager=QM1&Channel=SRV.CONN', repeat=True"
 ...
 Given a user of type "RestApi" load testing "http://example.com"
 ...
@@ -53,7 +55,7 @@ Then get request "fetch-document" from "/api/v1/document/{{ AtomicMessageQueue.d
 
 ### Using expression to get specific message
 
-And value of variable "AtomicMessageQueue.document_id" is "queue:IN.DOCUMENTS, expression:'//DocumentReference[text()='123abc']' | wait=120, url='mqs://mq_subscription:$conf::mq.password@mq.example.com/?QueueManager=QM1&Channel=SRV.CONN', repeat=True"
+And value for variable "AtomicMessageQueue.document_id" is "queue:IN.DOCUMENTS, expression:'//DocumentReference[text()='123abc']' | wait=120, url='mqs://mq_subscription:$conf::mq.password@mq.example.com/?QueueManager=QM1&Channel=SRV.CONN', repeat=True"
 And set response content type to "application/xml"
 ...
 Given a user of type "RestApi" load testing "http://example.com"
@@ -81,9 +83,9 @@ from grizzly_extras.async_message import AsyncMessageContext, AsyncMessageReques
 from grizzly_extras.arguments import split_value, parse_arguments
 from grizzly_extras.transformer import TransformerContentType
 
-from ...types import bool_typed, AtomicVariable
-from ...context import GrizzlyContext
+from ...types import RequestType, bool_typed
 from ..utils import resolve_variable
+from . import AtomicVariable
 
 try:
     import pymqi
@@ -123,11 +125,25 @@ def atomicmessagequeue__base_type__(value: str) -> str:
                 int(argument_value)
 
     # validate url
-    AtomicMessageQueue.create_context({
-        'url': arguments['url'],
-        'wait': arguments.get('wait', None),
-        'heartbeat_interval': arguments.get('heartbeat_interval', None),
-    })
+    url = arguments.get('url', None)
+    parsed = urlparse(url)
+
+    if parsed.scheme is None or parsed.scheme not in ['mq', 'mqs']:
+        raise ValueError(f'AtomicMessageQueue: "{parsed.scheme}" is not a supported scheme for url')
+
+    if parsed.hostname is None or len(parsed.hostname) < 1:
+        raise ValueError(f'AtomicMessageQueue: hostname is not specified in "{url}"')
+
+    if parsed.query == '':
+        raise ValueError(f'AtomicMessageQueue: QueueManager and Channel must be specified in the query string of "{url}"')
+
+    params = parse_qs(parsed.query)
+
+    if 'QueueManager' not in params:
+        raise ValueError('AtomicMessageQueue: QueueManager must be specified in the query string')
+
+    if 'Channel' not in params:
+        raise ValueError('AtomicMessageQueue: Channel must be specified in the query string')
 
     return f'{queue} | {queue_arguments}'
 
@@ -156,7 +172,7 @@ class AtomicMessageQueue(AtomicVariable[str]):
 
     def __init__(self, variable: str, value: str):
         if pymqi.__name__ == 'grizzly_extras.dummy_pymqi':
-            raise NotImplementedError('AtomicMessageQueue could not import pymqi, have you installed IBM MQ dependencies?')
+            pymqi.raise_for_error(self.__class__)
 
         # silence uamqp loggers
         for uamqp_logger_name in ['uamqp', 'uamqp.c_uamqp']:
@@ -195,26 +211,23 @@ class AtomicMessageQueue(AtomicVariable[str]):
             self._endpoint_clients = {variable: self.create_client(variable, settings)}
             self.__initialized = True
 
-    @classmethod
-    def create_context(cls, settings: Dict[str, Any]) -> AsyncMessageContext:
+    def create_context(self, settings: Dict[str, Any]) -> AsyncMessageContext:
         url = settings.get('url', None)
         parsed = urlparse(url)
 
         if parsed.scheme is None or parsed.scheme not in ['mq', 'mqs']:
-            raise ValueError(f'{cls.__name__}: "{parsed.scheme}" is not a supported scheme for url')
+            raise ValueError(f'{self.__class__.__name__}: "{parsed.scheme}" is not a supported scheme for url')
 
         if parsed.hostname is None or len(parsed.hostname) < 1:
-            raise ValueError(f'{cls.__name__}: hostname is not specified in "{url}"')
+            raise ValueError(f'{self.__class__.__name__}: hostname is not specified in "{url}"')
 
         if parsed.query == '':
-            raise ValueError(f'{cls.__name__}: QueueManager and Channel must be specified in the query string of "{url}"')
+            raise ValueError(f'{self.__class__.__name__}: QueueManager and Channel must be specified in the query string of "{url}"')
 
         paths: List[str] = []
 
-        grizzly = GrizzlyContext()
-
         for path in parsed.path.split('/'):
-            resolved = cast(str, resolve_variable(grizzly, path))
+            resolved = cast(str, resolve_variable(self.grizzly, path))
             paths.append(resolved)
 
         parsed = parsed._replace(path='/'.join(paths))
@@ -224,21 +237,21 @@ class AtomicMessageQueue(AtomicVariable[str]):
         parameters: List[str] = []
 
         for querystring in querystrings:
-            resolved = cast(str, resolve_variable(grizzly, querystrings[querystring][0]))
+            resolved = cast(str, resolve_variable(self.grizzly, querystrings[querystring][0]))
             parameters.append(f'{querystring}={resolved}')
 
         parsed = parsed._replace(query='&'.join(parameters))
 
         if '@' in parsed.netloc:
             credentials, host = parsed.netloc.split('@')
-            host = cast(str, resolve_variable(grizzly, host))
+            host = cast(str, resolve_variable(self.grizzly, host))
             credentials = credentials.replace('::', '%%')
             username, password = credentials.split(':', 1)
-            username = cast(str, resolve_variable(grizzly, username.replace('%%', '::')))
-            password = cast(str, resolve_variable(grizzly, password.replace('%%', '::')))
+            username = cast(str, resolve_variable(self.grizzly, username.replace('%%', '::')))
+            password = cast(str, resolve_variable(self.grizzly, password.replace('%%', '::')))
             host = f'{username}:{password}@{host}'
         else:
-            host = cast(str, resolve_variable(grizzly, parsed.netloc))
+            host = cast(str, resolve_variable(self.grizzly, parsed.netloc))
 
         parsed = parsed._replace(netloc=host)
 
@@ -247,10 +260,10 @@ class AtomicMessageQueue(AtomicVariable[str]):
         params = parse_qs(parsed.query)
 
         if 'QueueManager' not in params:
-            raise ValueError(f'{cls.__name__}: QueueManager must be specified in the query string')
+            raise ValueError(f'{self.__class__.__name__}: QueueManager must be specified in the query string')
 
         if 'Channel' not in params:
-            raise ValueError(f'{cls.__name__}: Channel must be specified in the query string')
+            raise ValueError(f'{self.__class__.__name__}: Channel must be specified in the query string')
 
         key_file: Optional[str] = None
         cert_label: Optional[str] = None
@@ -331,7 +344,7 @@ class AtomicMessageQueue(AtomicVariable[str]):
             # first request, connect to async-messaged
             if self._settings[variable].get('worker', None) is None:
                 request = {
-                    'action': 'CONN',
+                    'action': RequestType.CONNECT(),
                     'context': self._settings[variable]['context'],
                 }
 
