@@ -1,4 +1,6 @@
-'''This modules contains the means to transform a raw string to format that is possible to easy search
+'''
+@anchor pydoc:grizzly_extras.transformer Transformer
+This modules contains the means to transform a raw string to format that is possible to easy search
 for attributes and their value in.
 '''
 import re
